<?php
/*****************************************************************************
 *
 * pChartBarGraphLoad.php - Gadget for NagVis to diplay load as bar graph
 *
 * Copyright (c) 2004-2009 NagVis Project (Contact: lars@vertical-visions.de, michael_luebben@web.de)
 *
 * License:
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *****************************************************************************
 *
 * This is a simple gadget for NagVis. A gadget is a script which generates a
 * dynamic image for visualizing things as graphics in NagVis.
 *
 * The gadget gets its data from the NagVis frontend by parameters. This
 * gadget only needs the "perfdata" parameter. NagVis also passes the
 * following parameters to the gadgets:
 *  - name1:     Hostname
 *  - name2:     Service description
 *  - state:     Current state
 *  - stateType: Current state type (soft/hard)
 *
 *****************************************************************************/

// Load gadget core functions
require('./gadgets_core.php');

/*******************************************************************************
 * Start gadget main code
 ******************************************************************************/

header("Content-type: image/png");

//==========================================
// Set Minimum, Default, and Maximum values.
//==========================================

$min = 0;
$max = -1;
$default = 0; 
 
/* Now read the parameters */

$aOpts = Array('name1', 'name2', 'state', 'stateType', 'perfdata');
$aPerfdata = Array();

/**
 * Needed:
 *  perfdata=load1=0.960;5.000;10.000;0; load5=0.570;4.000;6.000;0; load15=0.540;3.000;4.000;0;
 *
 * Optional
 *  name1=localhost
 *  name2=Current Load
 *  state=OK
 *  stateType=HARD
 */

if(isset($_GET['perfdata']) && $_GET['perfdata'] != '') {
	$aOpts['perfdata'] = $_GET['perfdata'];
} else {
	errorBox('ERROR: The needed parameter "perfdata" is missing.');
}

if(isset($_GET['name1']) && $_GET['name1'] != '') {
	$aOpts['name1'] = $_GET['name1'];
}

if(isset($_GET['name2']) && $_GET['name2'] != '') {
	$aOpts['name2'] = $_GET['name2'];
}

if(isset($_GET['state']) && $_GET['state'] != '') {
	$aOpts['state'] = $_GET['state'];
}

if(isset($_GET['stateType']) && $_GET['stateType'] != '') {
	$aOpts['stateType'] = $_GET['stateType'];
}

/* Now parse the perfdata */
$aPerfdata = parsePerfdata($aOpts['perfdata']);

// This gadget is simple and dirty, it only recognizes the first dataset of
// performance data

$value = $aPerfdata[0]['value'];
$uom = $aPerfdata[0]['uom'];
$warn = $aPerfdata[0]['warning'];
$crit = $aPerfdata[0]['critical'];
$min = $aPerfdata[0]['min'];
$max = $aPerfdata[0]['max'];
$free = $max - $value;


// Draw pie chart and create image ouput
// Standard inclusions
include("./pChart/pChart/pData.class");
include("./pChart/pChart/pChart.class");
  
 // Dataset definition 
$DataSet = new pData;
$DataSet->AddPoint(array($aPerfdata[0]['value']),"Serie1");
$DataSet->AddPoint(array($aPerfdata[1]['value']),"Serie2");
$DataSet->AddPoint(array($aPerfdata[2]['value']),"Serie3");
$DataSet->AddAllSeries();
$DataSet->SetAbsciseLabelSerie();
$DataSet->SetSerieName("Load1","Serie1");
$DataSet->SetSerieName("Load5","Serie2");
$DataSet->SetSerieName("Load15","Serie3");

// Initialise the graph
$Graph = new pChart(290,220);
$Graph->setFontProperties("./pChart/Fonts/tahoma.ttf",8);
$Graph->setGraphArea(50,50,180,190);
$Graph->drawFilledRoundedRectangle(7,7,283,213,5,240,240,240);
$Graph->drawRoundedRectangle(5,5,285,215,5,230,230,230);
$Graph->drawGraphArea(255,255,255,TRUE);
$Graph->drawScale($DataSet->GetData(),$DataSet->GetDataDescription(),SCALE_NORMAL,150,150,150,TRUE,0,2,TRUE);   
$Graph->drawGrid(4,TRUE,230,230,230,50);

// Draw the 0 line
$Graph->setFontProperties("./pChart/Fonts/tahoma.ttf",6);
$Graph->drawTreshold(0,143,55,72,TRUE,TRUE);

// Draw the bar graph
$Graph->drawBarGraph($DataSet->GetData(),$DataSet->GetDataDescription(),TRUE);

// Finish the graph
$Graph->setFontProperties("./pChart/Fonts/tahoma.ttf",8);
$Graph->drawLegend(210,105,$DataSet->GetDataDescription(),255,255,255);
$Graph->setFontProperties("./pChart/Fonts/tahoma.ttf",9);
$Graph->drawTextBox(10,10,280,40,"\nLoad ".$aOpts['name1'],0,255,255,255,ALIGN_TOP_CENTER,FALSE,0,0,0,30);
  
$Graph->Stroke();
?>
